@@ -5,3 +5,5 @@ from pi_touch_gui.page import Page
 from pi_touch_gui.widget_buttons import *
 from pi_touch_gui.widget_controls import *
 from pi_touch_gui.widget_displays import *
+from pi_touch_gui.widget_functions import *
+from pi_touch_gui.function_registry import *
